Description Usage Arguments Details Functions See Also
Density, distribution function, and random generation for the k-aggregated discrete distributions
1 2 3 4 5 6 7 8 |
x |
vector of (non-negative integers) quantiles. |
k |
the additional number of mass to aggregate into the single mass. |
family |
character string partial matched from a list of base line distributions (Poisson, zero truncated Poisson, negative binomial, zero truncated negative binomial, Conway-Maxwell-Poisson, and zero truncated CMP distributions) |
param |
list of parameters to pass to the base line function. |
q |
vector of quantiles. |
n |
number of random number samples to return. |
For different base line distributions, a different set of parameters needs to be supplied through param: for families 'pois' and 'tpois', param$lambda cannot be NA; for families 'negbinom' and 'tnegbinom', param$size and param$logmu cannot be NA; for families 'cmp' and 'tcmp', param$lognu and param$logmu cannot be NA.
dkx: Density function for a k-aggregated distribution.
pkx: Distribution function for the k-aggregated distribution.
rkx: Random number generator for the k-aggregated distribution.
dcmp, dpois, dNegBinom
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.